# Test Runner Output

**Library:** xwformats  
**Layer:** main  
**Generated:** 14-Mar-2026 05:40:27.401  
**Runner:** TestRunner  

---

================================================================================
xwformats Test Runner - Hierarchical Orchestrator
================================================================================
**Test Directory:** `D:\OneDrive\DEV\exonware\xwformats\tests`
**Output File:** `D:\OneDrive\DEV\exonware\xwformats\docs\tests\TEST_20260314_053859_469_SUMMARY.md`

## Running All Test Layers
**Execution Order:** 0.core → 1.unit → 2.integration → 3.advance


## Layer 0: Core Tests

**Result:** ❌ ❌ FAILED

## Layer 1: Unit Tests

**Result:** ✅ ✅ PASSED

## Layer 2: Integration Tests

**Result:** ✅ ✅ PASSED

## Layer 3: Advance Tests

**Result:** ✅ ✅ PASSED

---

## 📊 Test Execution Summary


- **Total Layers:** 4
- **Passed:** 3
- **Failed:** 1

### ❌ SOME TESTS FAILED!

